@@ -21,13 +21,15 @@
 #include "relationship.h"
 
 Relationship::Relationship()
-: m_auto_create(false)
+: m_allow_edit(true), m_auto_create(false)
 {
+   m_translatable_item_type = TRANSLATABLE_TYPE_RELATIONSHIP;
 }
 
 Relationship::Relationship(const Relationship& src)
+: TranslatableItem(src)
 {
-  operator=(src);
+  operator=(src); //TODO_Performance: Implement properly.
 }
 
 Relationship::~Relationship()
@@ -36,12 +38,13 @@ Relationship::~Relationship()
 
 Relationship& Relationship::operator=(const Relationship& src)
 {
-  m_strName = src.m_strName;
-  m_strTitle = src.m_strTitle;  
+  TranslatableItem::operator=(src);
+
   m_strFrom_Table = src.m_strFrom_Table;
   m_strFrom_Field = src.m_strFrom_Field;
   m_strTo_Table = src.m_strTo_Table;
   m_strTo_Field = src.m_strTo_Field;
+  m_allow_edit = src.m_allow_edit;
   m_auto_create = src.m_auto_create;
 
   return *this;
@@ -49,15 +52,13 @@ Relationship& Relationship::operator=(const Relationship& src)
 
 bool Relationship::operator==(const Relationship& src) const
 {
-  bool bEqual = (m_strFrom_Table == src.m_strFrom_Table);
-  bEqual = bEqual && (m_strTitle == src.m_strTitle);
-  bEqual = bEqual && (m_strFrom_Field == src.m_strFrom_Field);
-  bEqual = bEqual && (m_strTo_Table == src.m_strTo_Table);
-  bEqual = bEqual && (m_strTo_Field == src.m_strTo_Field);
-  bEqual = bEqual && (m_strName == src.m_strName);
-  bEqual = bEqual && (m_auto_create == src.m_auto_create);
-
-  return bEqual;
+  return TranslatableItem::operator==(src)
+         && (m_strFrom_Table == src.m_strFrom_Table)
+         && (m_strFrom_Field == src.m_strFrom_Field)
+         && (m_strTo_Table == src.m_strTo_Table)
+         && (m_strTo_Field == src.m_strTo_Field)
+         && (m_allow_edit == src.m_allow_edit)
+         && (m_auto_create == src.m_auto_create);
 }
 
 Glib::ustring Relationship::get_from_table() const
@@ -100,39 +101,6 @@ void Relationship::set_to_field(const Glib::ustring& strVal)
   m_strTo_Field = strVal;
 }
 
-bool Relationship::get_name_not_empty() const
-{
-  return !m_strName.empty();
-}
-
-Glib::ustring Relationship::get_name() const
-{
-  return m_strName;
-}
-
-void Relationship::set_name(const Glib::ustring& strVal)
-{
-  m_strName = strVal;
-}
-
-Glib::ustring Relationship::get_title() const
-{
-  return m_strTitle;
-}
-
-void Relationship::set_title(const Glib::ustring& strVal)
-{
-  m_strTitle = strVal;
-}
-
-Glib::ustring Relationship::get_title_or_name() const
-{
-  if(m_strTitle.empty())
-    return m_strName;
-  else
-    return m_strTitle;
-}
-
 bool Relationship::get_auto_create() const
 {
   return m_auto_create;
@@ -142,3 +110,13 @@ void Relationship::set_auto_create(bool val)
 {
   m_auto_create = val;
 }
+
+bool Relationship::get_allow_edit() const
+{
+  return m_allow_edit;
+}
+
+void Relationship::set_allow_edit(bool val)
+{
+  m_allow_edit = val;
+}
