@@ -33,7 +33,7 @@ public:
   virtual ~Box_Data_Details();
 
   virtual bool init_db_details(const Glib::ustring& strTableName, const Gnome::Gda::Value& primary_key_value);
-  virtual bool refresh_data_from_database(const Gnome::Gda::Value& primary_key_value);
+  virtual bool refresh_data_from_database_with_primary_key(const Gnome::Gda::Value& primary_key_value);
   virtual bool refresh_data_from_database_blank();
 
   virtual void print_layout();
@@ -41,8 +41,8 @@ public:
   virtual Gnome::Gda::Value get_primary_key_value() const; //Actual primary key value of this record.
   virtual Gnome::Gda::Value get_primary_key_value_selected(); //Value in the primary key's cell.
 
-  virtual Gnome::Gda::Value get_entered_field_data(const LayoutItem_Field& field) const;
-  virtual void set_entered_field_data(const LayoutItem_Field& field, const Gnome::Gda::Value& value);
+  virtual Gnome::Gda::Value get_entered_field_data(const sharedptr<const LayoutItem_Field>& field) const;
+  virtual void set_entered_field_data(const sharedptr<const LayoutItem_Field>& field, const Gnome::Gda::Value& value);
 
   //Signals:
   typedef sigc::signal<void> type_signal_void;
@@ -51,23 +51,26 @@ public:
   type_signal_void signal_nav_next();
   type_signal_void signal_nav_last();
 
-  typedef sigc::signal<void, Gnome::Gda::Value> type_signal_record_deleted; //arg is PrimaryKey.   //TODO: pass by const ref?
+  typedef sigc::signal<void, const Gnome::Gda::Value&> type_signal_record_deleted; //arg is PrimaryKey.   //TODO: pass by const ref?
   type_signal_record_deleted signal_record_deleted();
 
-  //typedef sigc::signal<void, Glib::ustring, Gnome::Gda::Value> type_signal_user_requested_related_details; //args are TableName, PrimaryKey.
-  //type_signal_user_requested_related_details signal_user_requested_related_details();
+   /** For instance,
+    * void on_requested_related_details(const Glib::ustring& table_name, Gnome::Gda::Value primary_key_value);
+    */
+  typedef sigc::signal<void, const Glib::ustring&, Gnome::Gda::Value> type_signal_requested_related_details;
+  type_signal_requested_related_details signal_requested_related_details();
 
 protected:
   virtual bool fill_from_database(); //override.
   virtual void create_layout();
   //virtual void fill_related();
 
-  virtual void do_lookups(const Gtk::TreeModel::iterator& row, const LayoutItem_Field& field_changed, const Gnome::Gda::Value& field_value, const Field& primary_key, const Gnome::Gda::Value& primary_key_value);
-  virtual void refresh_related_fields(const Gtk::TreeModel::iterator& row, const LayoutItem_Field& field_changed, const Gnome::Gda::Value& field_value, const Field& primary_key, const Gnome::Gda::Value& primary_key_value);
+  virtual void do_lookups(const Gtk::TreeModel::iterator& row, const sharedptr<const LayoutItem_Field>& field_changed, const Gnome::Gda::Value& field_value, const sharedptr<const Field>& primary_key, const Gnome::Gda::Value& primary_key_value);
+  virtual void refresh_related_fields(const Gtk::TreeModel::iterator& row, const sharedptr<const LayoutItem_Field>& field_changed, const Gnome::Gda::Value& field_value, const sharedptr<const Field>& primary_key, const Gnome::Gda::Value& primary_key_value);
 
-  virtual bool get_field_primary_key(Field& field) const;
+  virtual sharedptr<Field> get_field_primary_key() const;
 
-  void print_layout_group(xmlpp::Element* node_parent, const LayoutGroup& group);
+  void print_layout_group(xmlpp::Element* node_parent, const sharedptr<const LayoutGroup>& group);
 
   //Signal handlers:
   virtual void on_button_new();
@@ -87,12 +90,16 @@ protected:
   //Signal handler: The last arg is bind-ed.
   //virtual void on_related_user_requested_details(Gnome::Gda::Value key_value, Glib::ustring strTableName);
 
-  virtual void on_flowtable_field_edited(const LayoutItem_Field& id, const Gnome::Gda::Value& value);
-  virtual void on_flowtable_related_record_changed(const Glib::ustring& relationship_name);
+  void on_flowtable_field_edited(const sharedptr<const LayoutItem_Field>& id, const Gnome::Gda::Value& value);
+  void on_flowtable_field_open_details_requested(const sharedptr<const LayoutItem_Field>& id, const Gnome::Gda::Value& value);
+  void on_flowtable_related_record_changed(const Glib::ustring& relationship_name);
+  void on_flowtable_requested_related_details(const Glib::ustring& table_name, Gnome::Gda::Value primary_key_value);
+
+  void on_flowtable_script_button_clicked(const sharedptr<const LayoutItem_Button>& layout_item);
 
   virtual void recalculate_fields_for_related_records(const Glib::ustring& relationship_name);
 
-  Field m_field_primary_key;
+  sharedptr<Field> m_field_primary_key;
   Gnome::Gda::Value m_primary_key_value;
 
   //Member widgets:
@@ -118,14 +125,13 @@ protected:
   bool m_bDoNotRefreshRelated; //Stops us from refreshing related records in response to an addition of a related record.
   bool m_ignore_signals;
 
-  //type_signal_user_requested_related_details m_signal_user_requested_related_details;
-
   type_signal_void m_signal_nav_first;
   type_signal_void m_signal_nav_prev;
   type_signal_void m_signal_nav_next;
   type_signal_void m_signal_nav_last;
 
   type_signal_record_deleted m_signal_record_deleted;
+  type_signal_requested_related_details m_signal_requested_related_details;
 };
 
 #endif //BOX_DATA_DETAILS_H
